@@ -18,7 +18,9 @@ from .services.vm_migration import VmMigrationAsyncClient, VmMigrationClient
 from .types.vmmigration import (
     AddGroupMigrationRequest,
     AddGroupMigrationResponse,
+    ApplianceVersion,
     AppliedLicense,
+    AvailableUpdates,
     CancelCloneJobRequest,
     CancelCloneJobResponse,
     CancelCutoverJobRequest,
@@ -76,6 +78,7 @@ from .types.vmmigration import (
     ListUtilizationReportsRequest,
     ListUtilizationReportsResponse,
     MigratingVm,
+    MigratingVmView,
     MigrationError,
     NetworkInterface,
     OperationMetadata,
@@ -97,6 +100,9 @@ from .types.vmmigration import (
     UpdateMigratingVmRequest,
     UpdateSourceRequest,
     UpdateTargetProjectRequest,
+    UpgradeApplianceRequest,
+    UpgradeApplianceResponse,
+    UpgradeStatus,
     UtilizationReport,
     UtilizationReportView,
     VmUtilizationInfo,
@@ -110,7 +116,9 @@ __all__ = (
     "VmMigrationAsyncClient",
     "AddGroupMigrationRequest",
     "AddGroupMigrationResponse",
+    "ApplianceVersion",
     "AppliedLicense",
+    "AvailableUpdates",
     "CancelCloneJobRequest",
     "CancelCloneJobResponse",
     "CancelCutoverJobRequest",
@@ -168,6 +176,7 @@ __all__ = (
     "ListUtilizationReportsRequest",
     "ListUtilizationReportsResponse",
     "MigratingVm",
+    "MigratingVmView",
     "MigrationError",
     "NetworkInterface",
     "OperationMetadata",
@@ -189,6 +198,9 @@ __all__ = (
     "UpdateMigratingVmRequest",
     "UpdateSourceRequest",
     "UpdateTargetProjectRequest",
+    "UpgradeApplianceRequest",
+    "UpgradeApplianceResponse",
+    "UpgradeStatus",
     "UtilizationReport",
     "UtilizationReportView",
     "VmMigrationClient",
